@@ -9,7 +9,7 @@ import os
 import sys
 
 from tiddlyweb.config import config, merge_config
-from tiddlyweb.store import Store
+from tiddlyweb.store import Store, NoBagError
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.model.user import User
 
@@ -187,9 +187,9 @@ def bag(args):
 
 @make_command()
 def tiddler(args):
-    """Import a single tiddler into an existing bag from stdin: <tiddler> <bag>"""
+    """Import a single tiddler into an existing bag from stdin: <bag> <tiddler>"""
     try:
-        tiddler_name, bag_name = args[0:3]
+        bag_name, tiddler_name = args[0:3]
     except (IndexError, ValueError), exc:
         print >> sys.stderr, 'you must include a tiddler and bag name: %s' % exc
         usage()
@@ -203,6 +203,61 @@ def tiddler(args):
     _put(tiddler, unicode(content, 'UTF-8'), 'text')
 
 
+@make_command()
+def lusers(args):
+    """List all the users on the system"""
+    store = _store()
+    users = store.list_users()
+    for user in users:
+        user = store.get(user)
+        print user.usersign, user.list_roles()
+
+
+@make_command()
+def lbags(args):
+    """List all the bags on the system."""
+    store = _store()
+    bags = store.list_bags()
+    serializer = Serializer('json')
+    for bag in bags:
+        bag = store.get(bag)
+        serializer.object = bag
+        print 'Name: %s' % bag.name
+        print serializer.to_string()
+        print
+
+
+@make_command()
+def lrecipes(args):
+    """List all the recipes on the system."""
+    store = _store()
+    recipes = store.list_recipes()
+    for recipe in recipes:
+        recipe = store.get(recipe)
+        print recipe.name, recipe.policy.owner
+
+
+@make_command()
+def ltiddlers(args):
+    """List all the tiddlers on the system. [<bag> <bag> <bag>] to limit."""
+    from tiddlyweb.model.bag import Bag
+    store = _store()
+    bags = [Bag(name) for name in args]
+    if not bags:
+        bags = store.list_bags()
+    try:
+        for bag in bags:
+            bag = store.get(bag)
+            print bag.name, bag.policy.owner
+            tiddlers = bag.list_tiddlers()
+            for tiddler in tiddlers:
+                tiddler = store.get(tiddler)
+                print '  ', tiddler.title, tiddler.modifier
+    except NoBagError, exc:
+        print >> sys.stderr, 'unable to inspect bag %s: %s' % (bag.name, exc)
+        usage()
+
+
 @make_command()
 def usage(*args):
     """List this help"""
