@@ -146,12 +146,27 @@ class Serialization(SerializationInterface):
         Make a list of the permissions the current user has
         on this tiddler.
         """
+        def _read_bag_perms(environ, tiddler):
+            perms = []
+            if 'tiddlyweb.usersign' in environ:
+                store = tiddler.store
+                if store:
+                    bag = Bag(tiddler.bag)
+                    bag.skinny = True
+                    bag = store.get(bag)
+                    perms = bag.policy.user_perms(
+                            environ['tiddlyweb.usersign'])
+            return perms
+
+        bag_name = tiddler.bag
         perms = []
-        bag = Bag(tiddler.bag)
-        if tiddler.store:
-            bag.skinny = True
-            bag = tiddler.store.get(bag)
-            if 'tiddlyweb.usersign' in self.environ:
-                perms = bag.policy.user_perms(
-                        self.environ['tiddlyweb.usersign'])
+        if hasattr(self, 'bag_perms_cache'):
+            if bag_name in self.bag_perms_cache:
+                perms = self.bag_perms_cache[bag_name]
+            else:
+                perms = _read_bag_perms(self.environ, tiddler)
+        else:
+            self.bag_perms_cache = {}
+            perms = _read_bag_perms(self.environ, tiddler)
+        self.bag_perms_cache[bag_name] = perms
         return perms
